@@ -1,5 +1,5 @@
 package Template::Liquid::Context;
-our $VERSION = '1.0.8';
+our $VERSION = '1.0.9';
 require Template::Liquid::Utility;
 require Template::Liquid::Error;
 use strict;
@@ -110,7 +110,7 @@ sub get {
         $var;
     my $cursor = \$s->{scopes}[-1];
     return $var
-        if $var =~ m[^-?\d+(\.\d+)?$]o
+        if $var =~ m[^[-\+]?(\d*\.)?\d+$]o
         && !exists $$cursor->{$path[0]};
     return     if $var eq '';
     return     if $var eq 'null';
@@ -151,7 +151,6 @@ STEP: while (@path) {
             $cursor = \$$cursor->[$crumb];
             next STEP;
         }
-        #die $var;
         return ();
     }
 }
