@@ -1,20 +1,25 @@
 package Template::Liquid::Filters;
-our $VERSION = '1.0.8';
+our $VERSION = '1.0.9';
 
 sub import {
     Template::Liquid::register_filter(
         qw[ date capitalize upcase downcase first last join split sort size
             strip_html strip_newlines newline_to_br replace replace_first remove
             remove_first truncate truncatewords prepend append minus plus times
-            divided_by modulo]
+            divided_by modulo round ceil floor abs money stock_price]
     );
 }
 
+sub round {
+    return if $_[0] !~ m[^(\d*\.)?\d+?$]o;
+    return sprintf '%.' . int($_[1] || 0) . 'f', $_[0];
+}
+
 sub date {
     $_[0] = time() if lc $_[0] eq 'now' || lc $_[0] eq 'today';
     $_[1] = defined $_[1] ? $_[1] : '%c';
     return $_[0]->strftime($_[1]) if ref $_[0] && $_[0]->can('strftime');
-    return if $_[0] !~ m[^(\d+\.)?\d+?$]o;
+    return if $_[0] !~ m[^(\d*\.)?\d+?$]o;
     require POSIX;
     return POSIX::strftime($_[1], gmtime($_[0]));
 }
@@ -22,7 +27,12 @@ sub capitalize { return ucfirst lc $_[0]; }
 sub upcase     { return uc $_[0] }
 sub downcase   { return lc $_[0] }
 sub first      { return @{$_[0]}[0] if ref $_[0] eq 'ARRAY'; }
-sub last       { return @{$_[0]}[-1] if ref $_[0] eq 'ARRAY'; }
+
+sub last {
+    my $ref = ref $_[0];
+    return substr $_[0], -1 if !$ref;
+    return @{$_[0]}[-1] if $ref eq 'ARRAY';
+}
 
 sub join {
     $_[1] = defined $_[1] ? $_[1] : ' ';
@@ -97,18 +107,18 @@ sub prepend { return (defined $_[1] ? $_[1] : '') . $_[0]; }
 sub append { return $_[0] . (defined $_[1] ? $_[1] : ''); }
 
 sub minus {
-    return $_[0] =~ m[^[\+-]?(\d+\.)?\d+?$]o
-        && $_[1] =~ m[^[\+-]?(\d+\.)?\d+?$]o ? $_[0] - $_[1] : ();
+    return $_[0] =~ m[^[\+-]?(\d*\.)?\d+?$]o
+        && $_[1] =~ m[^[\+-]?(\d*\.)?\d+?$]o ? $_[0] - $_[1] : ();
 }
 
 sub plus {
-    return $_[0] =~ m[^[\+-]?(\d+\.)?\d+?$]o
-        && $_[1] =~ m[^[\+-]?(\d+\.)?\d+?$]o ? $_[0] + $_[1] : $_[0] . $_[1];
+    return $_[0] =~ m[^[\+-]?(\d*\.)?\d+?$]o
+        && $_[1] =~ m[^[\+-]?(\d*\.)?\d+?$]o ? $_[0] + $_[1] : $_[0] . $_[1];
 }
 
 sub times {
-    return $_[0] if $_[1] !~ m[^[\+-]?(\d+\.)?\d+?$]o;
-    return $_[0] x $_[1] if $_[0] !~ m[^[\+-]?(\d+\.)?\d+?$]o;
+    return $_[0] if $_[1] !~ m[^[\+-]?(\d*\.)?\d+?$]o;
+    return $_[0] x $_[1] if $_[0] !~ m[^[\+-]?(\d*\.)?\d+?$]o;
     return $_[0] * $_[1];
 }
 sub divided_by { return $_[0] / $_[1]; }
@@ -119,6 +129,31 @@ sub modulo {
                         && $_[1] =~ m[[\+-]?[^\d\.]]o) ? $_[0] : $_[0] % $_[1]
     );
 }
+sub floor { int $_[0] }
+sub ceil  { int($_[0] + 1) }
+
+sub abs {
+    return CORE::abs($_[0]);
+}
+
+sub money {
+    return if $_[0] !~ m[^[\+-]?(\d*\.)?\d+?$]o;
+    return (  ($_[0] < 0     ? '-'   : '')
+            . (defined $_[1] ? $_[1] : '$')
+                . sprintf '%.2f',
+            CORE::abs($_[0])
+    );
+}
+
+sub stock_price {
+    return if $_[0] !~ m[^[\+-]?(\d*\.)?\d+?$]o;
+    return (  ($_[0] < 0     ? '-'   : '')
+            . (defined $_[1] ? $_[1] : '$')
+                . sprintf '%.'
+                . (int(CORE::abs($_[0])) > 0 ? 2 : 4) . 'f',
+            CORE::abs($_[0])
+    );
+}
 #
 # TODO
 #sub escape {...}    # Escape's HTML
@@ -126,6 +161,19 @@ sub modulo {
 #    ...;
 #} # returns an escaped version of html without affecting existing escaped entities
 #sub map {...}    # map/collect on a given property
+#url_encode
+#url_escape
+#url_param_escape
+#camelcase
+#handle/handleize
+#md5
+#sha1
+#sha256
+#hmac_sha1
+#hmac_sha256
+#newline_to_br
+#pluralize
+#   See https://help.shopify.com/themes/liquid/filters/string-filters
 1;
 
 =pod
@@ -136,6 +184,67 @@ sub modulo {
 
 Template::Liquid::Filters - Default Filters Based on Liquid's Standard Set
 
+=head1 Synopsis
+
+Filters are simple methods that modify the output of numbers, strings,
+variables and objects. They are placed within an output tag C<{{ }}> and are
+denoted by a pipe character C<|>.
+
+    # product.title = "Awesome Shoes"
+    {{ product.title | upcase }}
+    # Output: AWESOME SHOES
+
+In the example above, C<product> is the object, C<title> is its attribute, and
+C<upcase> is the filter being applied.
+
+Some filters require a parameter to be passed.
+
+    {{ product.title | remove: "Awesome" }}
+    # Output: Shoes
+
+Multiple filters can be used on one output. They are applied from left to
+right.
+
+    {{ product.title | upcase | remove: "AWESOME"  }}
+    # SHOES
+
+=head1 Array Filters
+
+Array filters change the output of arrays.
+
+=head2 C<join>
+
+Joins elements of the array with a certain character between them.
+
+    # Where array is [1..6]
+    {{ array | join }}      => 1 2 3 4 5 6
+    {{ array | join:', ' }} => 1, 2, 3, 4, 5, 6
+
+=head2 C<first>
+
+Get the first element of the passed in array
+
+    # Where array is [1..6]
+    {{ array | first }} => 1
+
+=head2 C<last>
+
+Get the last element of the passed in array.
+
+    # Where array is [1..6]
+    {{ array | last }} => 6
+
+You can use last with dot notation when you need to use the filter inside a
+tag.
+
+    {% if product.tags.last == "sale"%}
+        This product is on sale!
+    {% endif %}
+
+Using last on a string returns the last character in the string.
+
+    {{ product.title | last }}
+
 =head1 Standard Filters
 
 These are the current default filters. They have been written to behave
@@ -187,27 +296,6 @@ Convert an input string to lowercase using Perl's C<lc> function.
 
 Convert a input string to uppercase using Perl's C<uc> function.
 
-=head2 C<first>
-
-Get the first element of the passed in array
-
-    # Where array is [1..6]
-    {{ array | first }} => 1
-
-=head2 C<last>
-
-Get the last element of the passed in array.
-
-    # Where array is [1..6]
-    {{ array | last }} => 6
-
-=head2 C<join>
-
-Joins elements of the array with a certain character between them.
-
-    # Where array is [1..6]
-    {{ array | join }}      => 1 2 3 4 5 6
-    {{ array | join:', ' }} => 1, 2, 3, 4, 5, 6
 
 =head2 C<split>
 
@@ -368,6 +456,59 @@ Simple modulo operation.
 
     {{ 10 | modulo:3 }} => 1
 
+=head2 C<round>
+
+Rounds the output to the nearest integer or specified number of decimals.
+
+    {{ 4.6 | round }}       => 5
+    {{ 4.3 | round }}       => 4
+    {{ 4.5612 | round: 2 }} => 4.56
+
+=head2 C<money>
+
+Formats floats and integers as if they were money.
+
+    {{  4.6    | money }} => $4.60
+    {{ -4.3    | money }} => -$4.30
+    {{  4.5612 | money }} => $4.56
+
+You may pass a currency symbol to override the default dollar sign (C<$>).
+
+    {{  4.6    | money:'€' }} => €4.60
+
+=head2 C<stock_price>
+
+Formats floats and integers as if they were stock prices.
+
+    {{ 4.6    | stock_price }} => $4.60
+    {{ 0.30   | stock_price }} => $0.3000
+    {{ 4.5612 | stock_price }} => $4.56
+
+You may pass a currency symbol to override the default dollar sign (C<$>).
+
+    {{  4.6    | stock_price:'€' }} => €4.60
+
+=head2 C<abs>
+
+Returns the absolute value of a number.
+
+    {{  4 | abs }} => 4
+    {{ -4 | abs }} => 4
+
+=head2 C<ceil>
+
+Rounds an integer up to the nearest integer.
+
+    {{ 4.6 | ceil }} => 5
+    {{ 4.3 | ceil }} => 5
+
+=head2 C<floor>
+
+Rounds an integer down to the nearest integer.
+
+    {{ 4.6 | floor }} => 4
+    {{ 4.3 | floor }} => 4
+
 =head1 Author
 
 Sanko Robinson <sanko@cpan.org> - http://sankorobinson.com/
